import React from "react";

import "./label.css";

interface ClassLabelProps {
    text: string;
    color: string;
    width: number;
    active?: boolean;
    onClick?: (type: string) => void;
}

/**
 * Displays a small text label with an associated color strip (at the bottom).
 * @param text Text displayed in the label.
 * @param color Color of the color strip.
 * @param width Width of the color strip (the text will be left-aligned).
 * @param onClick Optional onClick handler.
 * @param active If false, the label will be displayed partially transparent.
 * @constructor
 */
function Label({
    text,
    color,
    width,
    onClick,
    active = true,
}: ClassLabelProps) {
    const handleClick = () => {
        if (onClick) {
            onClick(text);
        }
    };

    const opacity = active ? 1.0 : 0.4;
    return (
        <div
            className={"filter-class-label"}
            style={{ opacity }}
            onClick={handleClick}
        >
            <p>{text}</p>
            <div
                className={"filter-class-label-color-strip"}
                style={{ width: width + "px", backgroundColor: color }}
            ></div>
        </div>
    );
}

export default Label;
