import jQuery from "jquery";
import { state } from "./editor";
import { listAllSpaces, saveGraphJson } from "../../common/datasets";
import { SPACE } from "../../config";

/**
 * Initiates all the handlers for button presses and input changes.
 */
export function initInteractions() {
    jQuery("button#clear-collection").on("click", () => {
        state.clearSelectedItems();
    });

    jQuery("button#import-space-btn").on("click", () =>
        importSpaceFromInterface()
    );
    loadSpacesList();
}

function loadSpacesList() {
    var selectContainer = jQuery("#space-id-select");
    selectContainer.empty();
    listAllSpaces().then((spaces) => {
        spaces.forEach((space) => {
            var selectedTxt = "";
            if (space === SPACE) {
                selectedTxt = "selected ";
            }

            var child =
                "<option " +
                selectedTxt +
                'value="' +
                space +
                '">' +
                space +
                "</option>";
            selectContainer.append(child);
        });
    });
    selectContainer.val(SPACE);
}

function importSpaceFromInterface() {
    var json = undefined;
    try {
        console.log(jQuery("#import-space-area").val());
        json = JSON.parse(jQuery("#import-space-area").val());
    } catch (e) {
        console.log(e);
        alert('"Space JSON" not valid. Check console for details.');
        return;
    }

    var spaceName = jQuery("#import-space-name-text").val();
    if (spaceName.length == 0) {
        alert('"Space Name" cannot be empty.');
        return;
    }

    saveGraphJson(spaceName, json)
        .then(() => {
            loadSpacesList();
            alert("Space imported!");
        })
        .catch((ex) => {
            console.log(ex);
            alert(
                "Something went wrong, could not import space. Check console for further details."
            );
        });
}
